==> amazon_sagemaker_jupyter_scheduler-2.2.2.tar.gz: amazon_sagemaker_jupyter_scheduler-2.2.2/src/utils/PluginEnvironmentProvider.tsx <==
import { JupyterFrontEnd } from '@jupyterlab/application';
import React, { createContext, useContext, useState } from 'react';

export const STUDIO_SAGEMAKER_UI_PLUGIN_ID = '@amzn/sagemaker-ui:project';

enum PluginEnvironmentType {
  LocalJL = 'local-jupyter-lab',
  Studio = 'studio',
}

class PluginEnvironment {

  public get isStudio(): boolean {
    return this.type === PluginEnvironmentType.Studio;
  }

  public get isLocalJL(): boolean {
    return this.type === PluginEnvironmentType.LocalJL;
  }

  constructor(
    public readonly type: PluginEnvironmentType,
  ) { }

}

function getPluginEnvironment(app: JupyterFrontEnd): PluginEnvironment {
  if (app.hasPlugin(STUDIO_SAGEMAKER_UI_PLUGIN_ID)) {
    return new PluginEnvironment(PluginEnvironmentType.Studio);
  }

  return new PluginEnvironment(PluginEnvironmentType.LocalJL);
}

type PluginEnvironmentValue = {
  pluginEnvironment: PluginEnvironment;
  setPluginEnvironment: (state: PluginEnvironment) => void;
}

const PluginEnvironmentContext = createContext<PluginEnvironmentValue | undefined>(undefined);

type PluginEnvironmentProviderProps = {
  app: JupyterFrontEnd;
  children: React.ReactNode;
};

function PluginEnvironmentProvider({ app, children }: PluginEnvironmentProviderProps) {
  const [pluginEnvironment, setPluginEnvironment] = useState<PluginEnvironment>(() => {
    return getPluginEnvironment(app);
  });
  const value = { pluginEnvironment, setPluginEnvironment };
  return <PluginEnvironmentContext.Provider value={value}>{children}</PluginEnvironmentContext.Provider>
}

function usePluginEnvironment(): PluginEnvironmentValue {
  const context = useContext(PluginEnvironmentContext);
  if (context === undefined) {
    throw new Error('usePluginEnvironment must be used within a PluginEnvironmentProvider');
  }
  return context;
}

export { PluginEnvironmentProvider, usePluginEnvironment, PluginEnvironment, PluginEnvironmentType };

==> amazon_sagemaker_jupyter_scheduler-3.1.10.tar.gz: amazon_sagemaker_jupyter_scheduler-3.1.10/src/utils/PluginEnvironmentProvider.tsx <==
import { JupyterFrontEnd } from '@jupyterlab/application';
import React, { createContext, useContext, useState } from 'react';

export const STUDIO_SAGEMAKER_UI_PLUGIN_ID = '@amzn/sagemaker-ui:project';
export const JUPYTERLAB_SAGEMAKER_UI_PLUGIN_ID = '@amzn/sagemaker-jupyterlab-extensions:sessionmanagement';

enum PluginEnvironmentType {
  LocalJL = 'local-jupyter-lab',
  JupyterLab = 'jupyterlab',
  Studio = 'studio',
}

class PluginEnvironment {

  public get isStudio(): boolean {
    return this.type === PluginEnvironmentType.Studio;
  }

  public get isLocalJL(): boolean {
    return this.type === PluginEnvironmentType.LocalJL;
  }

  public get isJupyterLab(): boolean {
    return this.type === PluginEnvironmentType.JupyterLab;
  }

  public get isStudioOrJupyterLab(): boolean {
    return this.isStudio || this.isJupyterLab;
  }

  constructor(
    public readonly type: PluginEnvironmentType,
  ) { }

}

function getPluginEnvironment(app: JupyterFrontEnd): PluginEnvironment {
  if (app.hasPlugin(STUDIO_SAGEMAKER_UI_PLUGIN_ID)) {
    return new PluginEnvironment(PluginEnvironmentType.Studio);
  }

  if (app.hasPlugin(JUPYTERLAB_SAGEMAKER_UI_PLUGIN_ID)) {
    return new PluginEnvironment(PluginEnvironmentType.JupyterLab);
  }

  return new PluginEnvironment(PluginEnvironmentType.LocalJL);
}

type PluginEnvironmentValue = {
  pluginEnvironment: PluginEnvironment;
  setPluginEnvironment: (state: PluginEnvironment) => void;
}

const PluginEnvironmentContext = createContext<PluginEnvironmentValue | undefined>(undefined);

type PluginEnvironmentProviderProps = {
  app: JupyterFrontEnd;
  children: React.ReactNode;
};

function PluginEnvironmentProvider({ app, children }: PluginEnvironmentProviderProps) {
  const [pluginEnvironment, setPluginEnvironment] = useState<PluginEnvironment>(() => {
    return getPluginEnvironment(app);
  });
  const value = { pluginEnvironment, setPluginEnvironment };
  return <PluginEnvironmentContext.Provider value={value}>{children}</PluginEnvironmentContext.Provider>
}

function usePluginEnvironment(): PluginEnvironmentValue {
  const context = useContext(PluginEnvironmentContext);
  if (context === undefined) {
    throw new Error('usePluginEnvironment must be used within a PluginEnvironmentProvider');
  }
  return context;
}

export { PluginEnvironmentProvider, usePluginEnvironment, PluginEnvironment, PluginEnvironmentType };
